@@ -27,7 +27,7 @@ import gobject
 import gst
 
 from source import TimelineSource
-from objects import BrotherObjects, MEDIA_TYPE_AUDIO
+from objects import BrotherObjects
 from pitivi.serializable import to_object_from_data_type
 
 class Layer(BrotherObjects):
@@ -216,7 +216,7 @@ class TimelineComposition(TimelineSource):
     def __len__(self):
         """ return the number of sources in this composition """
         l = 0
-        for min, max, sources in self.sources:
+        for mn, mx, sources in self.sources:
             l += len(sources)
         return l
 
@@ -427,10 +427,10 @@ class TimelineComposition(TimelineSource):
         my_add_sorted(self.sources[position-1], source)
 
         # add it to self.gnlobject
-        self.gnlobject.info("adding %s to our composition" % source.gnlobject)
+        self.gnlobject.info("adding %s to our composition" % source.gnlobject.props.name)
         self.gnlobject.add(source.gnlobject)
 
-        self.gnlobject.info("added source %s" % source.gnlobject)
+        self.gnlobject.info("added source %s" % source.gnlobject.props.name)
         gst.info("%s" % str(self.sources))
         self.emit('source-added', source)
 
@@ -447,7 +447,7 @@ class TimelineComposition(TimelineSource):
         auto_linked : if True will add the brother (if any) of the given source
                 to the linked composition with the same parameters
         """
-        self.gnlobject.info("source %s , position:%d, self.sources:%s" %(source, position, self.sources))
+        self.gnlobject.info("source %s , position:%d, self.sources:%s" %(source.name, position, self.sources))
 
         # make sure object to add has valid start/duration
         if source.start == -1 or source.duration <= 0:
@@ -485,15 +485,15 @@ class TimelineComposition(TimelineSource):
         gst.info("start=%s, position=%d, existorder=%d, sourcelength=%s" % (gst.TIME_ARGS(start),
                                                                             position,
                                                                             existorder,
-                                                                            gst.TIME_ARGS(source.factory.length)))
+                                                                            gst.TIME_ARGS(source.factory.getDuration())))
         # set the correct start/duration time
-        duration = source.factory.length
+        duration = source.factory.getDuration()
         source.setStartDurationTime(start, duration)
 
         # pushing following
         if push_following and not position in [-1, 0]:
             #print self.gnlobject, "pushing following", existorder, len(self.sources[position - 1][2])
-            self.shiftSources(source.factory.length, existorder, len(self.sources[position - 1][2]))
+            self.shiftSources(source.factory.getDuration(), existorder, len(self.sources[position - 1][2]))
 
         self.addSource(source, position, auto_linked=auto_linked)
 
@@ -675,9 +675,9 @@ class TimelineComposition(TimelineSource):
         the given start position will be shifted.
         """
         self.gnlobject.info("offset:%d, startsource:%s, endsource:%s" % (offset, startsource, endsource))
-        startpos = self.getSourcePosition(startsource)
+        startpos = self.getSimpleSourcePosition(startsource)
         if endsource:
-            endpos = self.getSourcePosition(endsource)
+            endpos = self.getSimpleSourcePosition(endsource)
         else:
             endpos = -1
         self.shiftSources(offset, startpos, endpos)
@@ -701,7 +701,7 @@ class TimelineComposition(TimelineSource):
 
         # sources
         for layer in self.sources:
-            min, max, sources = layer
+            mn, mx, sources = layer
             for source in sources[:]:
                 self.removeSource(source)
 
@@ -709,13 +709,13 @@ class TimelineComposition(TimelineSource):
 
     def setDefaultSource(self, source):
         """
-        Adds a default source to the composition.
+        Adds a default TimelineSource to the composition.
         Default sources will be used for gaps within the composition.
         """
         if self.defaultSource:
-            self.gnlobject.remove(self.defaultSource)
-        source.props.priority = 2 ** 32 - 1
-        self.gnlobject.add(source)
+            self.gnlobject.remove(self.defaultSource.gnlobject)
+        source.gnlobject.props.priority = 2 ** 32 - 1
+        self.gnlobject.add(source.gnlobject)
         self.defaultSource = source
 
     def getDefaultSource(self):
@@ -769,7 +769,7 @@ class TimelineComposition(TimelineSource):
             # return the settings of our only source
             return self.sources[0][2][0].getExportSettings()
         else:
-            if self.media_type == MEDIA_TYPE_AUDIO:
+            if self.isAudio():
                 return self._autoAudioSettings()
             else:
                 return self._autoVideoSettings()
@@ -807,32 +807,64 @@ class TimelineComposition(TimelineSource):
     def fromDataFormat(self, obj):
         TimelineSource.fromDataFormat(self, obj)
 
-        # effects
+        # deserialize all objects
+        globalfx = []
+        simplefx = []
+        complexfx = []
+        transitions = []
+        layers = []
+
         if "global-effects" in obj:
             for fx in obj["global-effects"]:
-                self.global_effects.append(to_object_from_data_type(fx))
+                globalfx.append(to_object_from_data_type(fx))
+                #self.global_effects.append(to_object_from_data_type(fx))
         if "simple-effects" in obj:
             for line in obj["simple-effects"]:
                 tmp = []
                 for fx in line:
                     tmp.append(to_object_from_data_type(fx))
-                self.simple_effects.append(tmp)
+                simplefx.append(tmp)
+                #self.simple_effects.append(tmp)
         if "complex-effects" in obj:
             for fx in obj["complex-effects"]:
-                self.complex_effects.append(to_object_from_data_type(fx))
+                complexfx.append(to_object_from_data_type(fx))
+                #self.complex_effects.append(to_object_from_data_type(fx))
         if "transitions" in obj:
             for fx in obj["transitions"]:
-                self.transitions.append(to_object_from_data_type(fx))
+                transitions.append(to_object_from_data_type(fx))
+                #self.transitions.append(to_object_from_data_type(fx))
 
-        # sources
         # WARNING / FIXME / TODO : This is a temporary format !!!
         gst.log("recreating sources")
         pos = 1
         for layer in obj["sources"]:
+            tmp = []
             for source in layer:
-                self.addSource(to_object_from_data_type(source), pos)
+                tmp.append(to_object_from_data_type(source))
+            layers.append(tmp)
             pos += 1
 
+        gst.log("adding effects")
+        # add objects
+        for fx in globalfx:
+            self.global_effects.append(fx)
+        for lay in simplefx:
+            self.simple_effects.append(lay)
+        for fx in complexfx:
+            self.complex_effects.append(fx)
+        for fx in transitions:
+            self.transitions.append(fx)
+
+        gst.log("adding sources")
+        pos = 1
+        for layer in layers:
+            for source in layer:
+                self.addSource(source, pos, auto_linked=False)
+            pos +=1
+
         # default source
         if "default-source" in obj:
             self.setDefaultSource(to_object_from_data_type(obj["default-source"]))
+        gst.log("done adding sources")
+
+        self._updateCondensedList()
