@@ -212,10 +212,8 @@ class SourceListWidget(gtk.VBox):
             self._newProjectFailedCb)
 
         # default pixbufs
-        icontheme = gtk.icon_theme_get_default()
-        self.filepixbuf = icontheme.load_icon("misc", 32, 0)
-        self.audiofilepixbuf = icontheme.load_icon("audio-x-generic", 32, 0)
-        self.videofilepixbuf = icontheme.load_icon("video-x-generic", 32, 0)
+        self.audiofilepixbuf = self._getIcon("audio-x-generic", "pitivi-sound.png")
+        self.videofilepixbuf = self._getIcon("video-x-generic", "pitivi-video.png")
 
         # Drag and Drop
         self.drag_dest_set(gtk.DEST_DEFAULT_DROP | gtk.DEST_DEFAULT_MOTION,
@@ -235,6 +233,17 @@ class SourceListWidget(gtk.VBox):
         # Error dialog box
         self.errorDialogBox = None
 
+    def _getIcon(self, iconname, alternate):
+        icontheme = gtk.icon_theme_get_default()
+        pixdir = get_pixmap_dir()
+        icon = None
+        try:
+            icon = icontheme.load_icon(iconname, 32, 0)
+        finally:
+            if not icon:
+                icon = gtk.gdk.pixbuf_new_from_file(os.path.join(pixdir, alternate))
+        return icon
+
     def _connectToProject(self, project):
         """Connect signal handlers to a project.
 
@@ -288,7 +297,7 @@ class SourceListWidget(gtk.VBox):
             self.txtlabel.show()
             self.showingTreeView = False
 
-    def _dragMotionCb(self, unused_layout, unused_context, x, unused_y,
+    def _dragMotionCb(self, unused_layout, unused_context, unused_x, unused_y,
                       unused_timestamp):
         gst.log("motion")
         gobject.idle_add(self._displayTreeView, True, False)
@@ -326,13 +335,11 @@ class SourceListWidget(gtk.VBox):
         """ walks the trees of the folders in the list and adds the files it finds """
         instance.PiTiVi.threads.addThread(PathWalker, list, instance.PiTiVi.current.sources.addUris)
 
-    # sourcelist callbacks
-
-    def _fileAddedCb(self, unused_sourcelist, factory):
-        """ a file was added to the sourcelist """
+    def _addFactory(self, factory):
         try:
-            pixbuf = gtk.gdk.pixbuf_new_from_file(factory.thumbnail)
+            pixbuf = gtk.gdk.pixbuf_new_from_file(factory.getThumbnail())
         except:
+            gst.error("Failure to create thumbnail from file %s" % factory.getThumbnail())
             if factory.is_video:
                 thumbnail = self.videofilepixbuf
             elif factory.is_audio:
@@ -349,9 +356,15 @@ class SourceListWidget(gtk.VBox):
                                 factory.getPrettyInfo(),
                                 factory,
                                 factory.name,
-                                "<b>%s</b>" % beautify_length(factory.length)])
+                                factory.getDuration() and "<b>%s</b>" % beautify_length(factory.getDuration()) or ""])
         self._displayTreeView()
 
+    # sourcelist callbacks
+
+    def _fileAddedCb(self, unused_sourcelist, factory):
+        """ a file was added to the sourcelist """
+        self._addFactory(factory)
+
     def _fileRemovedCb(self, unused_sourcelist, uri):
         """ the given uri was removed from the sourcelist """
         # find the good line in the storemodel and remove it
@@ -375,7 +388,7 @@ class SourceListWidget(gtk.VBox):
     def _sourcesStoppedImportingCb(self, unused_sourcelist):
         self.infostub.stoppingImport()
 
-    def _removeInfoStub(self, infostub):
+    def _removeInfoStub(self, unused_i):
         self.remove(self.infostub)
 
     ## Error Dialog Box callbacks
@@ -428,13 +441,6 @@ class SourceListWidget(gtk.VBox):
             uri = model[path][COL_URI]
             del instance.PiTiVi.current.sources[uri]
 
-    def _errorDialogButtonClickedCb(self, unused_widget=None):
-        """ called when the user click on the import errors button """
-        if self.errorDialogBox:
-            self.errorDialogBox.show()
-        if self.errorDialogButton.parent:
-            self.bothbox.remove(self.errorDialogButton)
-
     def _playButtonClickedCb(self, unused_widget):
         """ Called when a user clicks on the play button """
         # get the selected filesourcefactory
@@ -457,29 +463,11 @@ class SourceListWidget(gtk.VBox):
     def _newProjectLoadedCb(self, unused_pitivi, project):
         # clear the storemodel
         self.storemodel.clear()
-
+        self._connectToProject(project)
         # synchronize the storemodel with the new project's sourcelist
         for uri, factory in project.sources:
-            if factory:
-                if factory.thumbnail:
-                    thumbnail = gtk.gdk.pixbuf_new_from_file(factory.thumbnail)
-                    desiredheight = (64 * thumbnail.get_height() /
-                        thumbnail.get_width())
-                    thumbnail = thumbnail.scale_simple(
-                        64, desiredheight, gtk.gdk.INTERP_BILINEAR)
-                name = os.path.basename(unquote(factory.name))
-                if factory.is_video:
-                    if not factory.thumbnail:
-                        thumbnail = self.videofilepixbuf
-                else:
-                    if not factory.thumbnail:
-                        thumbnail = self.audiofilepixbuf
-                # FIXME : update with new table structure (icon,
-                # infotext, objectfactory, uri)
-                self.storemodel.append([thumbnail, name, factory, factory.name,
-                    "<b>%s</b>" % beautify_length(factory.length)])
-
-        self._connectToProject(project)
+            gst.log("loading uri %s" % uri)
+            self._addFactory(factory)
 
     def _newProjectFailedCb(self, unused_pitivi, unused_reason,
         unused_uri):
@@ -504,7 +492,7 @@ class SourceListWidget(gtk.VBox):
         gst.debug("targetType:%d, selection.data:%r" % (targetType, selection.data))
         directories = []
         if targetType == dnd.TYPE_URI_LIST:
-            incoming = [x.strip('\x00') for x in selection.data.strip().split("\r\n") if x.strip('\x00')]
+            incoming = [unquote(x.strip('\x00')) for x in selection.data.strip().split("\r\n") if x.strip('\x00')]
             filenames = [x for x in incoming if isfile(x)]
             directories = [x for x in incoming if not isfile(x)]
         elif targetType == dnd.TYPE_TEXT_PLAIN:
